.. phydms documentation master file, created by
   sphinx-quickstart on Tue Mar 31 11:35:01 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for ``phydms``
==================================

`phydms`_ is a software package for **phy**\logenetic analyses using **d**\eep **m**\utational **s**\canning data to inform the substitution models.

`phydms`_ can use :ref:`ExpCM` to describe the evolution of protein-coding genes for phylogenetic analyses and the detection of sites of biologically interesting selection.

`phydms`_ is written in `Python`_ by `Bloom lab`_ (see the `full list of contributors`_).

:ref:`installation` of `phydms`_ will install :ref:`phydms_prog`, which performs the phylogenetic analyses. It also installs :ref:`auxiliary_progs` that facilitate model comparisons and visualization of the results. All of these programs are installed as command-line executables.

See :ref:`howtouse` for more details and a `tutorial <http://htmlpreview.github.io/?https://github.com/jbloomlab/phydms/blob/master/tutorial/phydms_tutorial.html>`_ on how to use `phydms`_.

The `phydms source code`_ is freely available under a `GPLv3`_ license.

If you use `phydms`_, please cite the references in :ref:`acknowledgments`.

Contents
------------

.. toctree::
   :maxdepth: 1

   installation
   howtouse
   phydms_prog
   auxiliary_progs
   ExpCM
   implementation
   phydmslib
   acknowledgments
   indices_and_tables

.. include:: weblinks.txt
